call_attr_proc_macro

Macro call_attr_proc_macro 

macro_rules! call_attr_proc_macro {
    (
        $implementations_mod_ident:ident,
        $exec_args_ident:ident,
        $exec_fn_mod_ident:ident,
        $item_ty:ty,
        $attr_tok_stream:ident,
        $item_tok_stream:ident
    ) => { ... };
}
Call an attribute proc-macro implementation function named exec.

This macro is proc-macro only. Call a proc-macro implementation function named exec, located in the given implementations module ident, with the given args type ident and type of the item for syn::parse_macro_input